@@ -1,5 +1,7 @@
+import asyncio
 from typing import (
     Any,
+    Awaitable,
     Callable,
     List,
     NoReturn,
@@ -59,10 +61,8 @@ from web3._utils.threads import (
 from web3._utils.transactions import (
     assert_valid_transaction_params,
     extract_valid_transaction_params,
-    get_buffered_gas_estimate,
     get_required_transaction,
     replace_transaction,
-    wait_for_transaction_receipt,
 )
 from web3.contract import (
     ConciseContract,
@@ -71,6 +71,7 @@ from web3.contract import (
 )
 from web3.exceptions import (
     TimeExhausted,
+    TransactionNotFound,
 )
 from web3.iban import (
     Iban,
@@ -82,12 +83,14 @@ from web3.method import (
 )
 from web3.module import (
     Module,
-    ModuleV2,
 )
 from web3.types import (
     ENS,
     BlockData,
     BlockIdentifier,
+    BlockParams,
+    CallOverrideParams,
+    FeeHistory,
     FilterParams,
     GasPriceStrategy,
     LogReceipt,
@@ -104,13 +107,361 @@ from web3.types import (
 )
 
 
-class Eth(ModuleV2, Module):
-    account = Account()
+class BaseEth(Module):
     _default_account: Union[ChecksumAddress, Empty] = empty
     _default_block: BlockIdentifier = "latest"
+    gasPriceStrategy = None
+
+    _gas_price: Method[Callable[[], Wei]] = Method(
+        RPC.eth_gasPrice,
+        mungers=None,
+    )
+
+    """ property default_block """
+    @property
+    def default_block(self) -> BlockIdentifier:
+        return self._default_block
+
+    @default_block.setter
+    def default_block(self, value: BlockIdentifier) -> None:
+        self._default_block = value
+
+    @property
+    def default_account(self) -> Union[ChecksumAddress, Empty]:
+        return self._default_account
+
+    def send_transaction_munger(self, transaction: TxParams) -> Tuple[TxParams]:
+        if 'from' not in transaction and is_checksum_address(self.default_account):
+            transaction = assoc(transaction, 'from', self.default_account)
+
+        return (transaction,)
+
+    _send_transaction: Method[Callable[[TxParams], HexBytes]] = Method(
+        RPC.eth_sendTransaction,
+        mungers=[send_transaction_munger]
+    )
+
+    _send_raw_transaction: Method[Callable[[Union[HexStr, bytes]], HexBytes]] = Method(
+        RPC.eth_sendRawTransaction,
+        mungers=[default_root_munger],
+    )
+
+    _get_transaction: Method[Callable[[_Hash32], TxData]] = Method(
+        RPC.eth_getTransactionByHash,
+        mungers=[default_root_munger]
+    )
+
+    _get_raw_transaction: Method[Callable[[_Hash32], HexBytes]] = Method(
+        RPC.eth_getRawTransactionByHash,
+        mungers=[default_root_munger]
+    )
+
+    """
+    `eth_getRawTransactionByBlockHashAndIndex`
+    `eth_getRawTransactionByBlockNumberAndIndex`
+    """
+    _get_raw_transaction_by_block: Method[Callable[[BlockIdentifier, int], HexBytes]] = Method(
+        method_choice_depends_on_args=select_method_for_block_identifier(
+            if_predefined=RPC.eth_getRawTransactionByBlockNumberAndIndex,
+            if_hash=RPC.eth_getRawTransactionByBlockHashAndIndex,
+            if_number=RPC.eth_getRawTransactionByBlockNumberAndIndex,
+        ),
+        mungers=[default_root_munger]
+    )
+
+    def _generate_gas_price(self, transaction_params: Optional[TxParams] = None) -> Optional[Wei]:
+        if self.gasPriceStrategy:
+            return self.gasPriceStrategy(self.web3, transaction_params)
+        return None
+
+    def set_gas_price_strategy(self, gas_price_strategy: GasPriceStrategy) -> None:
+        self.gasPriceStrategy = gas_price_strategy
+
+    def estimate_gas_munger(
+        self,
+        transaction: TxParams,
+        block_identifier: Optional[BlockIdentifier] = None
+    ) -> Sequence[Union[TxParams, BlockIdentifier]]:
+        if 'from' not in transaction and is_checksum_address(self.default_account):
+            transaction = assoc(transaction, 'from', self.default_account)
+
+        if block_identifier is None:
+            params: Sequence[Union[TxParams, BlockIdentifier]] = [transaction]
+        else:
+            params = [transaction, block_identifier]
+
+        return params
+
+    _estimate_gas: Method[Callable[..., Wei]] = Method(
+        RPC.eth_estimateGas,
+        mungers=[estimate_gas_munger]
+    )
+
+    _fee_history: Method[Callable[..., FeeHistory]] = Method(
+        RPC.eth_feeHistory,
+        mungers=[default_root_munger]
+    )
+
+    _max_priority_fee: Method[Callable[..., Wei]] = Method(
+        RPC.eth_maxPriorityFeePerGas,
+        mungers=None,
+    )
+
+    def get_block_munger(
+        self, block_identifier: BlockIdentifier, full_transactions: bool = False
+    ) -> Tuple[BlockIdentifier, bool]:
+        return (block_identifier, full_transactions)
+
+    """
+    `eth_getBlockByHash`
+    `eth_getBlockByNumber`
+    """
+    _get_block: Method[Callable[..., BlockData]] = Method(
+        method_choice_depends_on_args=select_method_for_block_identifier(
+            if_predefined=RPC.eth_getBlockByNumber,
+            if_hash=RPC.eth_getBlockByHash,
+            if_number=RPC.eth_getBlockByNumber,
+        ),
+        mungers=[get_block_munger],
+    )
+
+    get_block_number: Method[Callable[[], BlockNumber]] = Method(
+        RPC.eth_blockNumber,
+        mungers=None,
+    )
+
+    get_coinbase: Method[Callable[[], ChecksumAddress]] = Method(
+        RPC.eth_coinbase,
+        mungers=None,
+    )
+
+    def block_id_munger(
+        self,
+        account: Union[Address, ChecksumAddress, ENS],
+        block_identifier: Optional[BlockIdentifier] = None
+    ) -> Tuple[Union[Address, ChecksumAddress, ENS], BlockIdentifier]:
+        if block_identifier is None:
+            block_identifier = self.default_block
+        return (account, block_identifier)
+
+    def call_munger(
+        self,
+        transaction: TxParams,
+        block_identifier: Optional[BlockIdentifier] = None,
+        state_override: Optional[CallOverrideParams] = None,
+    ) -> Union[Tuple[TxParams, BlockIdentifier], Tuple[TxParams, BlockIdentifier, CallOverrideParams]]:  # noqa-E501
+        # TODO: move to middleware
+        if 'from' not in transaction and is_checksum_address(self.default_account):
+            transaction = assoc(transaction, 'from', self.default_account)
+
+        # TODO: move to middleware
+        if block_identifier is None:
+            block_identifier = self.default_block
+
+        if state_override is None:
+            return (transaction, block_identifier)
+        else:
+            return (transaction, block_identifier, state_override)
+
+    _get_accounts: Method[Callable[[], Tuple[ChecksumAddress]]] = Method(
+        RPC.eth_accounts,
+        mungers=None,
+    )
+
+    _get_hashrate: Method[Callable[[], int]] = Method(
+        RPC.eth_hashrate,
+        mungers=None,
+    )
+
+    _chain_id: Method[Callable[[], int]] = Method(
+        RPC.eth_chainId,
+        mungers=None,
+    )
+
+    _is_mining: Method[Callable[[], bool]] = Method(
+        RPC.eth_mining,
+        mungers=None,
+    )
+
+    _get_transaction_receipt: Method[Callable[[_Hash32], TxReceipt]] = Method(
+        RPC.eth_getTransactionReceipt,
+        mungers=[default_root_munger]
+    )
+
+
+class AsyncEth(BaseEth):
+    is_async = True
+
+    @property
+    async def accounts(self) -> Tuple[ChecksumAddress]:
+        return await self._get_accounts()  # type: ignore
+
+    @property
+    async def block_number(self) -> BlockNumber:
+        # types ignored b/c mypy conflict with BlockingEth properties
+        return await self.get_block_number()  # type: ignore
+
+    @property
+    async def chain_id(self) -> int:
+        return await self._chain_id()  # type: ignore
+
+    @property
+    async def coinbase(self) -> ChecksumAddress:
+        # types ignored b/c mypy conflict with BlockingEth properties
+        return await self.get_coinbase()  # type: ignore
+
+    @property
+    async def gas_price(self) -> Wei:
+        # types ignored b/c mypy conflict with BlockingEth properties
+        return await self._gas_price()  # type: ignore
+
+    @property
+    async def hashrate(self) -> int:
+        return await self._get_hashrate()  # type: ignore
+
+    @property
+    async def max_priority_fee(self) -> Wei:
+        return await self._max_priority_fee()  # type: ignore
+
+    @property
+    async def mining(self) -> bool:
+        return await self._is_mining()  # type: ignore
+
+    async def fee_history(
+            self,
+            block_count: int,
+            newest_block: Union[BlockParams, BlockNumber],
+            reward_percentiles: Optional[List[float]] = None
+    ) -> FeeHistory:
+        return await self._fee_history(  # type: ignore
+            block_count, newest_block, reward_percentiles)
+
+    async def send_transaction(self, transaction: TxParams) -> HexBytes:
+        # types ignored b/c mypy conflict with BlockingEth properties
+        return await self._send_transaction(transaction)  # type: ignore
+
+    async def send_raw_transaction(self, transaction: Union[HexStr, bytes]) -> HexBytes:
+        # types ignored b/c mypy conflict with BlockingEth properties
+        return await self._send_raw_transaction(transaction)  # type: ignore
+
+    async def get_transaction(self, transaction_hash: _Hash32) -> TxData:
+        # types ignored b/c mypy conflict with BlockingEth properties
+        return await self._get_transaction(transaction_hash)  # type: ignore
+
+    async def get_raw_transaction(self, transaction_hash: _Hash32) -> TxData:
+        # types ignored b/c mypy conflict with BlockingEth properties
+        return await self._get_raw_transaction(transaction_hash)  # type: ignore
+
+    async def get_raw_transaction_by_block(
+        self, block_identifier: BlockIdentifier, index: int
+    ) -> HexBytes:
+        # types ignored b/c mypy conflict with BlockingEth properties
+        return await self._get_raw_transaction_by_block(block_identifier, index)  # type: ignore
+
+    async def generate_gas_price(
+        self, transaction_params: Optional[TxParams] = None
+    ) -> Optional[Wei]:
+        return self._generate_gas_price(transaction_params)
+
+    async def estimate_gas(
+        self,
+        transaction: TxParams,
+        block_identifier: Optional[BlockIdentifier] = None
+    ) -> Wei:
+        # types ignored b/c mypy conflict with BlockingEth properties
+        return await self._estimate_gas(transaction, block_identifier)  # type: ignore
+
+    async def get_block(
+        self, block_identifier: BlockIdentifier, full_transactions: bool = False
+    ) -> BlockData:
+        # types ignored b/c mypy conflict with BlockingEth properties
+        return await self._get_block(block_identifier, full_transactions)  # type: ignore
+
+    _get_balance: Method[Callable[..., Awaitable[Wei]]] = Method(
+        RPC.eth_getBalance,
+        mungers=[BaseEth.block_id_munger],
+    )
+
+    async def get_balance(
+        self,
+        account: Union[Address, ChecksumAddress, ENS],
+        block_identifier: Optional[BlockIdentifier] = None
+    ) -> Wei:
+        return await self._get_balance(account, block_identifier)
+
+    _get_code: Method[Callable[..., Awaitable[HexBytes]]] = Method(
+        RPC.eth_getCode,
+        mungers=[BaseEth.block_id_munger]
+    )
+
+    async def get_code(
+        self,
+        account: Union[Address, ChecksumAddress, ENS],
+        block_identifier: Optional[BlockIdentifier] = None
+    ) -> HexBytes:
+        return await self._get_code(account, block_identifier)
+
+    _get_transaction_count: Method[Callable[..., Awaitable[Nonce]]] = Method(
+        RPC.eth_getTransactionCount,
+        mungers=[BaseEth.block_id_munger],
+    )
+
+    async def get_transaction_count(
+        self,
+        account: Union[Address, ChecksumAddress, ENS],
+        block_identifier: Optional[BlockIdentifier] = None
+    ) -> Nonce:
+        return await self._get_transaction_count(account, block_identifier)
+
+    _call: Method[Callable[..., Awaitable[Union[bytes, bytearray]]]] = Method(
+        RPC.eth_call,
+        mungers=[BaseEth.call_munger]
+    )
+
+    async def get_transaction_receipt(
+        self, transaction_hash: _Hash32
+    ) -> TxReceipt:
+        return await self._get_transaction_receipt(transaction_hash)  # type: ignore
+
+    async def wait_for_transaction_receipt(
+        self, transaction_hash: _Hash32, timeout: float = 120, poll_latency: float = 0.1
+    ) -> TxReceipt:
+        async def _wait_for_tx_receipt_with_timeout(
+            _tx_hash: _Hash32, _poll_latence: float
+        ) -> TxReceipt:
+            while True:
+                try:
+                    tx_receipt = await self._get_transaction_receipt(_tx_hash)  # type: ignore
+                except TransactionNotFound:
+                    tx_receipt = None
+                if tx_receipt is not None:
+                    break
+                await asyncio.sleep(poll_latency)
+            return tx_receipt
+        try:
+            return await asyncio.wait_for(
+                _wait_for_tx_receipt_with_timeout(transaction_hash, poll_latency),
+                timeout=timeout,
+            )
+        except asyncio.TimeoutError:
+            raise TimeExhausted(
+                f"Transaction {HexBytes(transaction_hash) !r} is not in the chain "
+                f"after {timeout} seconds"
+            )
+
+    async def call(
+        self,
+        transaction: TxParams,
+        block_identifier: Optional[BlockIdentifier] = None,
+        state_override: Optional[CallOverrideParams] = None,
+    ) -> Union[bytes, bytearray]:
+        return await self._call(transaction, block_identifier, state_override)
+
+
+class Eth(BaseEth):
+    account = Account()
     defaultContractFactory: Type[Union[Contract, ConciseContract, ContractCaller]] = Contract  # noqa: E704,E501
     iban = Iban
-    gasPriceStrategy = None
 
     def namereg(self) -> NoReturn:
         raise NotImplementedError()
@@ -148,37 +499,17 @@ class Eth(ModuleV2, Module):
     def syncing(self) -> Union[SyncStatus, bool]:
         return self.is_syncing()
 
-    get_coinbase: Method[Callable[[], ChecksumAddress]] = Method(
-        RPC.eth_coinbase,
-        mungers=None,
-    )
-
     @property
     def coinbase(self) -> ChecksumAddress:
         return self.get_coinbase()
 
-    is_mining: Method[Callable[[], bool]] = Method(
-        RPC.eth_mining,
-        mungers=None,
-    )
-
     @property
     def mining(self) -> bool:
-        return self.is_mining()
-
-    get_hashrate: Method[Callable[[], int]] = Method(
-        RPC.eth_hashrate,
-        mungers=None,
-    )
+        return self._is_mining()
 
     @property
     def hashrate(self) -> int:
-        return self.get_hashrate()
-
-    _gas_price: Method[Callable[[], Wei]] = Method(
-        RPC.eth_gasPrice,
-        mungers=None,
-    )
+        return self._get_hashrate()
 
     @property
     def gas_price(self) -> Wei:
@@ -192,19 +523,9 @@ class Eth(ModuleV2, Module):
         )
         return self.gas_price
 
-    get_accounts: Method[Callable[[], Tuple[ChecksumAddress]]] = Method(
-        RPC.eth_accounts,
-        mungers=None,
-    )
-
     @property
     def accounts(self) -> Tuple[ChecksumAddress]:
-        return self.get_accounts()
-
-    get_block_number: Method[Callable[[], BlockNumber]] = Method(
-        RPC.eth_blockNumber,
-        mungers=None,
-    )
+        return self._get_accounts()
 
     @property
     def block_number(self) -> BlockNumber:
@@ -218,11 +539,6 @@ class Eth(ModuleV2, Module):
         )
         return self.block_number
 
-    _chain_id: Method[Callable[[], int]] = Method(
-        RPC.eth_chainId,
-        mungers=None,
-    )
-
     @property
     def chain_id(self) -> int:
         return self._chain_id()
@@ -236,7 +552,6 @@ class Eth(ModuleV2, Module):
         return self.chain_id
 
     """ property default_account """
-
     @property
     def default_account(self) -> Union[ChecksumAddress, Empty]:
         return self._default_account
@@ -261,15 +576,10 @@ class Eth(ModuleV2, Module):
         )
         self._default_account = account
 
-    """ property default_block """
-
-    @property
-    def default_block(self) -> BlockIdentifier:
-        return self._default_block
-
-    @default_block.setter
-    def default_block(self, value: BlockIdentifier) -> None:
-        self._default_block = value
+    get_balance: Method[Callable[..., Wei]] = Method(
+        RPC.eth_getBalance,
+        mungers=[BaseEth.block_id_munger],
+    )
 
     @property
     def defaultBlock(self) -> BlockIdentifier:
@@ -287,19 +597,9 @@ class Eth(ModuleV2, Module):
         )
         self._default_block = value
 
-    def block_id_munger(
-        self,
-        account: Union[Address, ChecksumAddress, ENS],
-        block_identifier: Optional[BlockIdentifier] = None
-    ) -> Tuple[Union[Address, ChecksumAddress, ENS], BlockIdentifier]:
-        if block_identifier is None:
-            block_identifier = self.default_block
-        return (account, block_identifier)
-
-    get_balance: Method[Callable[..., Wei]] = Method(
-        RPC.eth_getBalance,
-        mungers=[block_id_munger],
-    )
+    @property
+    def max_priority_fee(self) -> Wei:
+        return self._max_priority_fee()
 
     def get_storage_at_munger(
         self,
@@ -336,27 +636,14 @@ class Eth(ModuleV2, Module):
         mungers=[get_proof_munger],
     )
 
+    def get_block(
+        self, block_identifier: BlockIdentifier, full_transactions: bool = False
+    ) -> BlockData:
+        return self._get_block(block_identifier, full_transactions)
+
     get_code: Method[Callable[..., HexBytes]] = Method(
         RPC.eth_getCode,
-        mungers=[block_id_munger]
-    )
-
-    def get_block_munger(
-        self, block_identifier: BlockIdentifier, full_transactions: bool = False
-    ) -> Tuple[BlockIdentifier, bool]:
-        return (block_identifier, full_transactions)
-
-    """
-    `eth_getBlockByHash`
-    `eth_getBlockByNumber`
-    """
-    get_block: Method[Callable[..., BlockData]] = Method(
-        method_choice_depends_on_args=select_method_for_block_identifier(
-            if_predefined=RPC.eth_getBlockByNumber,
-            if_hash=RPC.eth_getBlockByHash,
-            if_number=RPC.eth_getBlockByNumber,
-        ),
-        mungers=[get_block_munger],
+        mungers=[BaseEth.block_id_munger]
     )
 
     """
@@ -398,10 +685,16 @@ class Eth(ModuleV2, Module):
         mungers=[default_root_munger]
     )
 
-    get_transaction: Method[Callable[[_Hash32], TxData]] = Method(
-        RPC.eth_getTransactionByHash,
-        mungers=[default_root_munger]
-    )
+    def get_transaction(self, transaction_hash: _Hash32) -> TxData:
+        return self._get_transaction(transaction_hash)
+
+    def get_raw_transaction(self, transaction_hash: _Hash32) -> _Hash32:
+        return self._get_raw_transaction(transaction_hash)
+
+    def get_raw_transaction_by_block(
+        self, block_identifier: BlockIdentifier, index: int
+    ) -> HexBytes:
+        return self._get_raw_transaction_by_block(block_identifier, index)
 
     def getTransactionFromBlock(
         self, block_identifier: BlockIdentifier, transaction_index: int
@@ -428,26 +721,34 @@ class Eth(ModuleV2, Module):
         return self.wait_for_transaction_receipt(transaction_hash, timeout, poll_latency)
 
     def wait_for_transaction_receipt(
-        self, transaction_hash: _Hash32, timeout: int = 120, poll_latency: float = 0.1
+        self, transaction_hash: _Hash32, timeout: float = 120, poll_latency: float = 0.1
     ) -> TxReceipt:
         try:
-            return wait_for_transaction_receipt(self.web3, transaction_hash, timeout, poll_latency)
+            with Timeout(timeout) as _timeout:
+                while True:
+                    try:
+                        tx_receipt = self._get_transaction_receipt(transaction_hash)
+                    except TransactionNotFound:
+                        tx_receipt = None
+                    if tx_receipt is not None:
+                        break
+                    _timeout.sleep(poll_latency)
+            return tx_receipt
+
         except Timeout:
             raise TimeExhausted(
-                "Transaction {} is not in the chain, after {} seconds".format(
-                    to_hex(transaction_hash),
-                    timeout,
-                )
+                f"Transaction {HexBytes(transaction_hash) !r} is not in the chain "
+                f"after {timeout} seconds"
             )
 
-    get_transaction_receipt: Method[Callable[[_Hash32], TxReceipt]] = Method(
-        RPC.eth_getTransactionReceipt,
-        mungers=[default_root_munger]
-    )
+    def get_transaction_receipt(
+        self, transaction_hash: _Hash32
+    ) -> TxReceipt:
+        return self._get_transaction_receipt(transaction_hash)
 
     get_transaction_count: Method[Callable[..., Nonce]] = Method(
         RPC.eth_getTransactionCount,
-        mungers=[block_id_munger],
+        mungers=[BaseEth.block_id_munger],
     )
 
     @deprecated_for("replace_transaction")
@@ -475,29 +776,11 @@ class Eth(ModuleV2, Module):
         new_transaction = merge(current_transaction_params, transaction_params)
         return replace_transaction(self.web3, current_transaction, new_transaction)
 
-    def send_transaction_munger(self, transaction: TxParams) -> Tuple[TxParams]:
-        # TODO: move to middleware
-        if 'from' not in transaction and is_checksum_address(self.default_account):
-            transaction = assoc(transaction, 'from', self.default_account)
+    def send_transaction(self, transaction: TxParams) -> HexBytes:
+        return self._send_transaction(transaction)
 
-        # TODO: move gas estimation in middleware
-        if 'gas' not in transaction:
-            transaction = assoc(
-                transaction,
-                'gas',
-                get_buffered_gas_estimate(self.web3, transaction),
-            )
-        return (transaction,)
-
-    send_transaction: Method[Callable[[TxParams], HexBytes]] = Method(
-        RPC.eth_sendTransaction,
-        mungers=[send_transaction_munger]
-    )
-
-    send_raw_transaction: Method[Callable[[Union[HexStr, bytes]], HexBytes]] = Method(
-        RPC.eth_sendRawTransaction,
-        mungers=[default_root_munger],
-    )
+    def send_raw_transaction(self, transaction: Union[HexStr, bytes]) -> HexBytes:
+        return self._send_raw_transaction(transaction)
 
     def sign_munger(
         self,
@@ -524,45 +807,25 @@ class Eth(ModuleV2, Module):
         mungers=[default_root_munger],
     )
 
-    def call_munger(
-        self,
-        transaction: TxParams,
-        block_identifier: Optional[BlockIdentifier] = None
-    ) -> Tuple[TxParams, BlockIdentifier]:
-        # TODO: move to middleware
-        if 'from' not in transaction and is_checksum_address(self.default_account):
-            transaction = assoc(transaction, 'from', self.default_account)
-
-        # TODO: move to middleware
-        if block_identifier is None:
-            block_identifier = self.default_block
-
-        return (transaction, block_identifier)
-
     call: Method[Callable[..., Union[bytes, bytearray]]] = Method(
         RPC.eth_call,
-        mungers=[call_munger]
+        mungers=[BaseEth.call_munger]
     )
 
-    def estimate_gas_munger(
+    def estimate_gas(
         self,
         transaction: TxParams,
         block_identifier: Optional[BlockIdentifier] = None
-    ) -> Sequence[Union[TxParams, BlockIdentifier]]:
-        if 'from' not in transaction and is_checksum_address(self.default_account):
-            transaction = assoc(transaction, 'from', self.default_account)
+    ) -> Wei:
+        return self._estimate_gas(transaction, block_identifier)
 
-        if block_identifier is None:
-            params: Sequence[Union[TxParams, BlockIdentifier]] = [transaction]
-        else:
-            params = [transaction, block_identifier]
-
-        return params
-
-    estimate_gas: Method[Callable[..., Wei]] = Method(
-        RPC.eth_estimateGas,
-        mungers=[estimate_gas_munger]
-    )
+    def fee_history(
+        self,
+        block_count: int,
+        newest_block: Union[BlockParams, BlockNumber],
+        reward_percentiles: Optional[List[float]] = None
+    ) -> FeeHistory:
+        return self._fee_history(block_count, newest_block, reward_percentiles)
 
     def filter_munger(
         self,
@@ -669,30 +932,27 @@ class Eth(ModuleV2, Module):
 
     @deprecated_for("generate_gas_price")
     def generateGasPrice(self, transaction_params: Optional[TxParams] = None) -> Optional[Wei]:
-        return self.generate_gas_price(transaction_params)
+        return self._generate_gas_price(transaction_params)
 
     def generate_gas_price(self, transaction_params: Optional[TxParams] = None) -> Optional[Wei]:
-        if self.gasPriceStrategy:
-            return self.gasPriceStrategy(self.web3, transaction_params)
-        return None
+        return self._generate_gas_price(transaction_params)
 
     @deprecated_for("set_gas_price_strategy")
     def setGasPriceStrategy(self, gas_price_strategy: GasPriceStrategy) -> None:
         return self.set_gas_price_strategy(gas_price_strategy)
 
-    def set_gas_price_strategy(self, gas_price_strategy: GasPriceStrategy) -> None:
-        self.gasPriceStrategy = gas_price_strategy
-
     # Deprecated Methods
     getBalance = DeprecatedMethod(get_balance, 'getBalance', 'get_balance')
     getStorageAt = DeprecatedMethod(get_storage_at, 'getStorageAt', 'get_storage_at')
-    getBlock = DeprecatedMethod(get_block, 'getBlock', 'get_block')
+    getBlock = DeprecatedMethod(get_block, 'getBlock', 'get_block')  # type: ignore
     getBlockTransactionCount = DeprecatedMethod(get_block_transaction_count,
                                                 'getBlockTransactionCount',
                                                 'get_block_transaction_count')
     getCode = DeprecatedMethod(get_code, 'getCode', 'get_code')
     getProof = DeprecatedMethod(get_proof, 'getProof', 'get_proof')
-    getTransaction = DeprecatedMethod(get_transaction, 'getTransaction', 'get_transaction')
+    getTransaction = DeprecatedMethod(get_transaction,   # type: ignore
+                                      'getTransaction',
+                                      'get_transaction')
     getTransactionByBlock = DeprecatedMethod(get_transaction_by_block,
                                              'getTransactionByBlock',
                                              'get_transaction_by_block')
@@ -701,17 +961,19 @@ class Eth(ModuleV2, Module):
                                            'get_transaction_count')
     getUncleByBlock = DeprecatedMethod(get_uncle_by_block, 'getUncleByBlock', 'get_uncle_by_block')
     getUncleCount = DeprecatedMethod(get_uncle_count, 'getUncleCount', 'get_uncle_count')
-    sendTransaction = DeprecatedMethod(send_transaction, 'sendTransaction', 'send_transaction')
+    sendTransaction = DeprecatedMethod(send_transaction,  # type: ignore
+                                       'sendTransaction',
+                                       'send_transaction')
     signTransaction = DeprecatedMethod(sign_transaction, 'signTransaction', 'sign_transaction')
     signTypedData = DeprecatedMethod(sign_typed_data, 'signTypedData', 'sign_typed_data')
     submitHashrate = DeprecatedMethod(submit_hashrate, 'submitHashrate', 'submit_hashrate')
     submitWork = DeprecatedMethod(submit_work, 'submitWork', 'submit_work')
     getLogs = DeprecatedMethod(get_logs, 'getLogs', 'get_logs')
-    estimateGas = DeprecatedMethod(estimate_gas, 'estimateGas', 'estimate_gas')
-    sendRawTransaction = DeprecatedMethod(send_raw_transaction,
+    estimateGas = DeprecatedMethod(estimate_gas, 'estimateGas', 'estimate_gas')  # type: ignore
+    sendRawTransaction = DeprecatedMethod(send_raw_transaction,  # type: ignore
                                           'sendRawTransaction',
                                           'send_raw_transaction')
-    getTransactionReceipt = DeprecatedMethod(get_transaction_receipt,
+    getTransactionReceipt = DeprecatedMethod(get_transaction_receipt,  # type: ignore
                                              'getTransactionReceipt',
                                              'get_transaction_receipt')
     uninstallFilter = DeprecatedMethod(uninstall_filter, 'uninstallFilter', 'uninstall_filter')
